public inbox for igt-dev@lists.freedesktop.org
 help / color / mirror / Atom feed
From: "José Roberto de Souza" <jose.souza@intel.com>
To: igt-dev@lists.freedesktop.org
Subject: [igt-dev] [PATCH v2 2/4] tests/kms_frontbuffer_tracking: Improve tiling test coverage
Date: Tue, 10 Mar 2020 17:42:33 -0700	[thread overview]
Message-ID: <20200311004235.138072-2-jose.souza@intel.com> (raw)
In-Reply-To: <20200311004235.138072-1-jose.souza@intel.com>

Lets add some more tiling tests, if tiling is supported by FBC draw
some rectangles and compare the CRC against benchmark if not
supported run the test to guarantee that FBC is disabled.

This is a preparation for when kernel will allow FBC to be enabled
without fences, so we can better test linear and Y tiled
frontbuffers.

v2:
- renamed tile to tiling (Ville)
- removed *-tiling-x test (Ville)
- improved tiling_disable_fbc_subtest documentation (Ville)

Cc: Ville Syrjälä <ville.syrjala@linux.intel.com>
Signed-off-by: José Roberto de Souza <jose.souza@intel.com>
---
 tests/kms_frontbuffer_tracking.c | 53 +++++++++++++++++++++++++-------
 1 file changed, 42 insertions(+), 11 deletions(-)

diff --git a/tests/kms_frontbuffer_tracking.c b/tests/kms_frontbuffer_tracking.c
index c4deb72b..12ba9bba 100644
--- a/tests/kms_frontbuffer_tracking.c
+++ b/tests/kms_frontbuffer_tracking.c
@@ -2170,6 +2170,23 @@ static void format_draw_subtest(const struct test_mode *t)
 		badformat_subtest(t);
 }
 
+static bool tiling_is_valid(int feature_flags, enum tiling_type tiling)
+{
+	if (!(feature_flags & FEATURE_FBC))
+		return true;
+
+	switch (tiling) {
+	case TILING_LINEAR:
+		return false;
+	case TILING_X:
+	case TILING_Y:
+		return true;
+	default:
+		igt_assert(false);
+		return false;
+	}
+}
+
 /*
  * slow_draw - sleep a little bit between drawing operations
  *
@@ -2975,22 +2992,22 @@ static void stridechange_subtest(const struct test_mode *t)
 }
 
 /**
- * tilingchange - alternate between tiled and untiled in multiple ways
+ * tiling_disable_fbc_subtest - Check if tiling is unsupported by FBC
  *
  * METHOD
  *   This test alternates between tiled and untiled frontbuffers of the same
  *   size and format through multiple different APIs: the page flip IOCTL,
  *   normal modesets and the plane APIs.
  *
  * EXPECTED RESULTS
  *   FBC gets properly disabled for the untiled FB and reenabled for the
  *   tiled FB.
  *
  * FAILURES
  *   Bad Kernels may somehow leave FBC enabled, which can cause FIFO underruns
  *   that lead to CRC assertion failures.
  */
-static void tilingchange_subtest(const struct test_mode *t)
+static void tiling_disable_fbc_subtest(const struct test_mode *t)
 {
 	struct igt_fb new_fb, *old_fb;
 	struct modeset_params *params = pick_params(t);
@@ -3001,13 +3018,13 @@ static void tilingchange_subtest(const struct test_mode *t)
 	old_fb = params->primary.fb;
 
 	create_fb(t->format, params->primary.fb->width, params->primary.fb->height,
-		  LOCAL_DRM_FORMAT_MOD_NONE, t->plane, &new_fb);
+		  t->tiling, t->plane, &new_fb);
 	fill_fb(&new_fb, COLOR_PRIM_BG);
 
 	for (flip_type = 0; flip_type < FLIP_COUNT; flip_type++) {
 		igt_debug("Flip type: %d\n", flip_type);
 
-		/* Set a buffer with no tiling. */
+		/* Set a buffer with new tiling. */
 		params->primary.fb = &new_fb;
 		page_flip_for_params(params, flip_type);
 		do_assertions(ASSERT_FBC_DISABLED);
@@ -3513,8 +3530,22 @@ igt_main_args("", long_options, help_str, opt_handler, NULL)
 			igt_subtest_f("%s-stridechange", feature_str(t.feature))
 				stridechange_subtest(&t);
 
-			igt_subtest_f("%s-tilingchange", feature_str(t.feature))
-				tilingchange_subtest(&t);
+			for (t.tiling = TILING_LINEAR; t.tiling < TILING_COUNT;
+			     t.tiling++) {
+				if (t.tiling == TILING_X)
+					continue;
+
+				igt_subtest_f("%s-tiling-%s",
+					      feature_str(t.feature),
+					      tiling_str(t.tiling)) {
+
+					if (tiling_is_valid(t.feature, t.tiling))
+						draw_subtest(&t);
+					else
+						tiling_disable_fbc_subtest(&t);
+				}
+			}
+			t.tiling = opt.tiling;
 		}
 
 		if ((t.feature & FEATURE_PSR) || (t.feature & FEATURE_DRRS))
@@ -2975,22 +2992,22 @@ static void stridechange_subtest(const struct test_mode *t)
  *
  * METHOD
- *   This test alternates between tiled and untiled frontbuffers of the same
- *   size and format through multiple different APIs: the page flip IOCTL,
- *   normal modesets and the plane APIs.
+ *   This test alternates between a FBC supported and non-supported tiled
+ *   frontbuffers of the same size and format through multiple different
+ *   APIs: the page flip IOCTL, normal modesets and the plane APIs.
  *
  * EXPECTED RESULTS
@@ -2975,22 +2992,22 @@ static void stridechange_subtest(const struct test_mode *t)
  *
  * EXPECTED RESULTS
- *   FBC gets properly disabled for the untiled FB and reenabled for the
- *   tiled FB.
+ *   FBC gets properly disabled for the non-supported tiling and reenabled for
+ *   the supported tiling.
  *
  * FAILURES
-- 
2.25.1

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

  reply	other threads:[~2020-03-11  0:41 UTC|newest]

Thread overview: 10+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-03-11  0:42 [igt-dev] [PATCH v2 1/4] tests/kms_frontbuffer_tracking: Add tiling to test_mode José Roberto de Souza
2020-03-11  0:42 ` José Roberto de Souza [this message]
2020-03-11  0:42 ` [igt-dev] [PATCH v2 3/4] tests/kms_frontbuffer_tracking: Enable positive test on linear tiling José Roberto de Souza
2020-03-11  7:30   ` Petri Latvala
2020-03-11 16:57     ` Souza, Jose
2020-03-11  0:42 ` [igt-dev] [PATCH v2 4/4] DO_NOT_MERGE: Revert "tests/kms_frontbuffer_tracking: Enable positive test on linear tiling" José Roberto de Souza
2020-03-11  5:34 ` [igt-dev] ✗ GitLab.Pipeline: failure for series starting with [v2,1/4] tests/kms_frontbuffer_tracking: Add tiling to test_mode Patchwork
2020-03-11 17:26   ` Souza, Jose
2020-03-11  9:23 ` [igt-dev] ✓ Fi.CI.BAT: success " Patchwork
2020-03-11 21:20 ` [igt-dev] ✗ Fi.CI.IGT: failure " Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200311004235.138072-2-jose.souza@intel.com \
    --to=jose.souza@intel.com \
    --cc=igt-dev@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox